@@ -27,7 +27,7 @@ def createInputbyModel(model, data_points, data_shape=DEFAULT_INPUT_SHAPE):
     return (x, y)
 
 
-def convertModelToRawData(model, columns, num_data, batch_input_shape=None, num_dim=NUM_DIM):
+def convertModelToRawData(model, num_data, columns=[], batch_input_shape=None, num_dim=NUM_DIM):
     """
     Given a model, convert model conf into dataframe
     The columns of dataframe depends on the global variable options
@@ -78,7 +78,7 @@ def convertRawDataToModel(df):
     optimizer = df.optimizer.unique()[0]
     loss = df.loss.unique()[0]
     num_data = df.num_data.unique()[0]
-    batch_input_shape = df[[x for x in df.columns if "out_dim" in x]].dropna(axis=1).values[0]
+    batch_input_shape = df[[x for x in df.columns if "out_dim" in x]].iloc[0].dropna().values
     model = Sequential()
     drop_cols = ["active", "optimizer", "layer", "loss", "num_data", *[x for x in df.columns if "out_dim" in x]]
     for i in range(df.shape[0]):
